summaryrefslogtreecommitdiffstats
path: root/lib/compatibility/kmdi/qextmdi/kmdichildfrmcaption.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/compatibility/kmdi/qextmdi/kmdichildfrmcaption.h')
-rw-r--r--lib/compatibility/kmdi/qextmdi/kmdichildfrmcaption.h17
1 files changed, 9 insertions, 8 deletions
diff --git a/lib/compatibility/kmdi/qextmdi/kmdichildfrmcaption.h b/lib/compatibility/kmdi/qextmdi/kmdichildfrmcaption.h
index 4151f0c0..b3c8d88a 100644
--- a/lib/compatibility/kmdi/qextmdi/kmdichildfrmcaption.h
+++ b/lib/compatibility/kmdi/qextmdi/kmdichildfrmcaption.h
@@ -6,8 +6,8 @@
// begin : 07/1999 by Szymon Stefanek as part of kvirc
// (an IRC application)
// changes : 09/1999 by Falk Brettschneider to create an
-// - 06/2000 stand-alone Qt extension set of
-// classes and a Qt-based library
+// - 06/2000 stand-alone TQt extension set of
+// classes and a TQt-based library
// 2000-2003 maintained by the KDevelop project
//
// copyright : (C) 1999-2003 by Falk Brettschneider
@@ -41,14 +41,15 @@ class KMdiChildFrmCaptionPrivate;
*
* It's the caption bar of a child frame widget.
*/
-class KMDI_EXPORT KMdiChildFrmCaption : public QWidget
+class KMDI_EXPORT KMdiChildFrmCaption : public TQWidget
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructor
*/
- KMdiChildFrmCaption( KMdiChildFrm *parent );
+ KMdiChildFrmCaption( KMdiChildFrm *tqparent );
/**
* Destructor
@@ -88,7 +89,7 @@ protected:
virtual void mousePressEvent( TQMouseEvent * );
/**
* Calls maximizePressed of the parent widget ( KMdiChildFrm )
*/
virtual void mouseDoubleClickEvent( TQMouseEvent * );
@@ -117,7 +118,7 @@ public:
protected: // Protected attributes
/**
- * parent widget
+ * tqparent widget
*/
KMdiChildFrm *m_pParent;
@@ -127,7 +128,7 @@ protected: // Protected attributes
bool m_bActive;
/**
* the position offset related to its parent widget (internally used for translating mouse move positions
*/
TQPoint m_offset;
@@ -142,4 +143,4 @@ private:
#endif //_KMDICAPTION_H_
-// kate: space-indent off; replace-tabs off; indent-mode csands; tab-width 4;
+// kate: space-indent off; tqreplace-tabs off; indent-mode csands; tab-width 4;
@@ -88,7 +89,7 @@ protected:
virtual void mousePressEvent( TQMouseEvent * );
/**
- * Calls maximizePressed of the parent widget ( KMdiChildFrm )
+ * Calls maximizePressed of the tqparent widget ( KMdiChildFrm )
*/
virtual void mouseDoubleClickEvent( TQMouseEvent * );
@@ -127,7 +128,7 @@ protected: // Protected attributes
bool m_bActive;
/**
- * the position offset related to its parent widget (internally used for translating mouse move positions
+ * the position offset related to its tqparent widget (internally used for translating mouse move positions
*/
TQPoint m_offset;